@@ -9,7 +9,10 @@ class Relation(Field):
 class RelationList(List):
     implements(IRelationList)
 
-    value_type = Relation()
+    def __init__(self, value_type=None, unique=False, **kw):
+        if value_type is None:
+            value_type = Relation()
+        super(RelationList, self).__init__(value_type=value_type, unique=unique, **kw)
 
 class RelationChoice(Choice):
     implements(IRelationChoice)
\ No newline at end of file
